import { Components, Parameter, Schema, Paths, Path, Operation, Reference, RequestBody, Response } from '@openapi-integration/openapi-schema';

declare class DefinitionsResolver {
    private components?;
    resolvedDefinitions: any;
    static of(components?: Components): DefinitionsResolver;
    constructor(components?: Components | undefined);
    scanDefinitions: () => this;
    toDeclarations: () => string[];
}

interface IResolvedParams {
    pathParams: string[];
    queryParams: string[];
    bodyParams: string[];
    formDataParams: string[];
}
interface IResolvedPath extends IResolvedParams {
    THeader: Record<string, any>;
    TReq: Record<string, any> | undefined;
    TResp: Record<string, any> | string;
    bodyParams: string[];
    pathParams: string[];
    queryParams: string[];
    formDataParams: string[];
    method: string;
    operationId?: string;
    requestBody?: string;
    url: string;
}
interface IParameters {
    pathParams: Parameter[];
    queryParams: Parameter[];
    bodyParams: Parameter[];
    formDataParams: Parameter[];
}
declare type TDictionary<T> = {
    [key: string]: T;
};
interface ISchemaResolverInputs {
    results: TDictionary<any>;
    schema?: Schema;
    key?: string;
    parentKey?: string;
}

declare class SchemaResolver {
    private inputs;
    private schemaType;
    static of(inputs: ISchemaResolverInputs): SchemaResolver;
    constructor(inputs: ISchemaResolverInputs);
    getSchemaType: () => string | TDictionary<any>;
    resolve: (type?: string | undefined) => this;
    resolveNullable: () => this;
    getEnumName: (propertyName: string, parentKey?: string) => string;
    resolveRef: ($ref?: string | undefined, type?: string | undefined) => string;
    getBasicType: (basicType?: string, advancedType?: string | undefined) => string;
    getTypeForArray: (advancedType?: string | undefined) => string;
    pickTypeByRef: (str?: string | undefined) => string | undefined;
    resolveItems: (items?: Schema | Schema[] | undefined, type?: string | undefined, key?: string | undefined, parentKey?: string | undefined) => Record<string, any> | string;
    resolveProperties: (properties?: {
        [propertyName: string]: Schema;
    }, required?: string[], parentKey?: string | undefined) => TDictionary<any>;
}

declare class PathResolver {
    private paths;
    resolvedPaths: IResolvedPath[];
    extraDefinitions: {};
    contentType: {
        [operationId: string]: string;
    };
    static of(paths: Paths): PathResolver;
    constructor(paths: Paths);
    resolve: () => this;
    resolvePath(path: Path, pathName: string): {
        requestBody?: string | undefined;
        pathParams: any[];
        queryParams: any[];
        bodyParams: any[];
        formDataParams: any[];
        operationId: string | undefined;
        TResp: string | TDictionary<any>;
        TReq: any;
        THeader: {};
        url: string;
        method: string;
    }[];
    getRequestURL: (pathName: string) => string;
    isPathParam: (str: string) => boolean;
    resolveOperation: (operation: Operation) => {
        requestBody?: string | undefined;
        pathParams: any[];
        queryParams: any[];
        bodyParams: any[];
        formDataParams: any[];
        operationId: string | undefined;
        TResp: string | TDictionary<any>;
        TReq: any;
        THeader: {};
    };
    getParamsNames: (params: IParameters) => {
        pathParams: any[];
        queryParams: any[];
        bodyParams: any[];
        formDataParams: any[];
    };
    getRequestTypes: (params: IParameters, operationId: string, requestBody?: Reference | RequestBody | undefined) => any;
    getPathParamsTypes: (pathParams: Parameter[]) => {};
    getBodyAndQueryParamsTypes: (bodyParams: Parameter[]) => {};
    getFormDataParamsTypes: (formDataParams: any[]) => any;
    getResponseTypes: (responses: {
        [responseName: string]: Reference | Response;
    }) => string | TDictionary<any>;
    pickParams: (parameters: Parameter[]) => (type: "path" | "query" | "body" | "cookie" | "header") => Parameter[];
    getContentType(operationId: string, key: string): void;
    getRequestBodyTypes(operationId: string, requestBody?: RequestBody | Reference): {};
    getRequestBodyName(requestBody?: RequestBody | Reference, operationId?: string): {
        requestBody: string;
    } | undefined;
}

export { DefinitionsResolver, PathResolver, SchemaResolver };
